@@ -1,4 +1,5 @@
 #include "invoiceoperations.h"
+#include "configmanager.h"
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -14,6 +15,11 @@ InvoiceOperations::InvoiceOperations(QObject *parent)
 {
 }
 
+void InvoiceOperations::setConfigManager(ConfigManager *mgr)
+{
+    configManager = mgr;
+}
+
 bool InvoiceOperations::createInvoiceFolder(
     const QString &invoiceFile,
     const QString &targetBasePath,
@@ -130,6 +136,16 @@ void InvoiceOperations::createDirectoryFile(
     out << "CreatedAt=" << QDateTime::currentDateTime().toString(Qt::ISODate) << "\n";
     out << "ProcessedBy=" << user << "\n";
     out << "Reviewed=" << (reviewed ? "true" : "false") << "\n";
+    if (reviewed && configManager) {
+        QString reviewedText = configManager->getReviewedText();
+        QString reviewedTextDe = configManager->getReviewedTextDe();
+        if (!reviewedText.isEmpty()) {
+            out << "ReviewedText=" << reviewedText << "\n";
+        }
+        if (!reviewedTextDe.isEmpty()) {
+            out << "ReviewedText[de]=" << reviewedTextDe << "\n";
+        }
+    }
     if (!comment.isEmpty()) {
         out << "Note=" << comment << "\n";
     }
@@ -269,6 +285,42 @@ bool InvoiceOperations::createNoticeFile(const QString &folderPath, const QStrin
     return true;
 }
 
+bool InvoiceOperations::appendNoticeFile(const QString &folderPath, const QString &noticeText)
+{
+    if (noticeText.isEmpty()) {
+        return true;
+    }
+
+    // Find existing notice file in folder
+    QDir dir(folderPath);
+    QStringList noticeFiles = dir.entryList(QStringList() << "*_Notice.txt", QDir::Files);
+
+    QString noticeFilePath;
+    if (noticeFiles.isEmpty()) {
+        // Create new notice file with current date !FIXME! Should be removed in favor of perpetual nitice 
+        QString currentDate = QDate::currentDate().toString("yyyy-MM-dd");
+        noticeFilePath = folderPath + "/" + currentDate + "_Notice.txt";
+    } else {
+        // Use existing notice file
+        noticeFilePath = folderPath + "/" + noticeFiles.first();
+    }
+
+    QFile noticeFile(noticeFilePath);
+
+    if (!noticeFile.open(QIODevice::Append | QIODevice::Text)) {
+        workflowLogger.logError("Notice", "Failed to append to notice file: " + noticeFilePath);
+        return false;
+    }
+
+    QTextStream out(&noticeFile);
+    QString currentDateTime = QDateTime::currentDateTime().toString("yyyy-MM-dd HH:mm");
+    out << "\n--- " << currentDateTime << " ---\n";
+    out << noticeText << "\n";
+    noticeFile.close();
+
+    return true;
+}
+
 QVariantMap InvoiceOperations::loadInvoiceMetadata(const QString &filePath)
 {
     QVariantMap result;
@@ -316,7 +368,7 @@ QVariantMap InvoiceOperations::loadInvoiceMetadata(const QString &filePath)
     result["note"] = settings.value("Note", "").toString();
     settings.endGroup();
 
-    // Store the folder path for potential update operations
+    // Store the folder path for potential update operations !FIXME! find the best way to migrate to a new filename for the folder
     result["folderPath"] = parentDir;
     result["hasMetadata"] = true;
 
@@ -360,7 +412,7 @@ bool InvoiceOperations::updateInvoiceMetadata(
     QString oldNote = oldSettings.value("Note", "").toString();
     oldSettings.endGroup();
 
-    // Detect changes
+    // Detect changes !FIXME! Maybe far to complex... I need better Ideas
     if (oldReceiptDate != receiptStamp) changes << QString("ReceiptDate: %1 -> %2").arg(oldReceiptDate, receiptStamp);
     if (oldIssueDate != date) changes << QString("IssueDate: %1 -> %2").arg(oldIssueDate, date);
     if (oldSeller != sender) changes << QString("Seller: %1 -> %2").arg(oldSeller, sender);
@@ -408,6 +460,16 @@ bool InvoiceOperations::updateInvoiceMetadata(
     out << "UpdatedAt=" << QDateTime::currentDateTime().toString(Qt::ISODate) << "\n";
     out << "ProcessedBy=" << user << "\n";
     out << "Reviewed=" << (reviewed ? "true" : "false") << "\n";
+    if (reviewed && configManager) {
+        QString reviewedText = configManager->getReviewedText();
+        QString reviewedTextDe = configManager->getReviewedTextDe();
+        if (!reviewedText.isEmpty()) {
+            out << "ReviewedText=" << reviewedText << "\n";
+        }
+        if (!reviewedTextDe.isEmpty()) {
+            out << "ReviewedText[de]=" << reviewedTextDe << "\n";
+        }
+    }
     if (!comment.isEmpty()) {
         out << "Note=" << comment << "\n";
     }
@@ -429,7 +491,7 @@ QString InvoiceOperations::getNextVersionedFilename(const QString &folderPath, c
         return baseName;
     }
 
-    // Find the next available version number
+    // Find the next available version number !FIXME! Maybe this is not a good idea for versioning
     int version = 2;
     while (true) {
         QString versionedName = QString("%1_v%2").arg(baseName).arg(version);
@@ -447,3 +509,102 @@ QString InvoiceOperations::getNextVersionedFilename(const QString &folderPath, c
         }
     }
 }
+
+bool InvoiceOperations::cancelInvoice(
+    const QString &folderPath,
+    const QString &archivePath,
+    const QString &reason,
+    const QString &user,
+    const QString &cancelledIcon)
+{
+    if (folderPath.isEmpty() || archivePath.isEmpty() || reason.isEmpty() || user.isEmpty()) {
+        workflowLogger.logError("Cancel", "Required fields missing");
+        return false;
+    }
+
+    QString directoryFilePath = folderPath + "/.directory";
+    if (!QFile::exists(directoryFilePath)) {
+        workflowLogger.logError("Cancel", "Directory file not found: " + directoryFilePath);
+        return false;
+    }
+
+    // Load existing metadata
+    QSettings settings(directoryFilePath, QSettings::IniFormat);
+
+    settings.beginGroup("X-XRDialog-Invoice");
+    QString invoiceId = settings.value("ID", "").toString();
+    QString seller = settings.value("Seller", "").toString();
+    QString receiptDate = settings.value("ReceiptDate", "").toString();
+    QString issueDate = settings.value("IssueDate", "").toString();
+    QString budgetCode = settings.value("BuyerReference", "").toString();
+    QString amount = settings.value("PayableAmount", "").toString();
+    settings.endGroup();
+
+    // Write updated .directory with cancelled status
+    QFile directoryFile(directoryFilePath);
+    if (!directoryFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
+        workflowLogger.logError("Cancel", "Failed to write directory file");
+        return false;
+    }
+
+    QTextStream out(&directoryFile);
+
+    // [Desktop Entry] - freedesktop.org standard fields
+    out << "[Desktop Entry]\n";
+    out << "Type=Directory\n";
+    out << "Name=" << invoiceId << " - " << seller << " [CANCELLED]\n";
+    out << "Name[de]=" << invoiceId << " - " << seller << " [STORNIERT]\n";
+    out << "GenericName=Cancelled Invoice\n";
+    out << "GenericName[de]=Stornierte Rechnung\n";
+    out << "Comment=CANCELLED by " << user << ": " << invoiceId << " - " << seller << "\n";
+    out << "Comment[de]=STORNIERT von " << user << ": " << invoiceId << " - " << seller << "\n";
+    out << "Icon=" << cancelledIcon << "\n";
+    out << "Keywords=" << seller << ";" << invoiceId << ";" << budgetCode << ";Cancelled;Storniert;\n";
+
+    // [X-XRDialog-Invoice] - vendor-specific invoice data (preserved)
+    out << "\n[X-XRDialog-Invoice]\n";
+    out << "FormatVersion=1.0\n";
+    out << "ReceiptDate=" << receiptDate << "\n";
+    out << "IssueDate=" << issueDate << "\n";
+    out << "Seller=" << seller << "\n";
+    out << "ID=" << invoiceId << "\n";
+    out << "BuyerReference=" << budgetCode << "\n";
+    if (!amount.isEmpty()) {
+        out << "PayableAmount=" << amount << "\n";
+        out << "PayableCurrency=EUR\n";
+    }
+
+    // [X-XRDialog-Processing] - vendor-specific processing data
+    out << "\n[X-XRDialog-Processing]\n";
+    out << "CancelledAt=" << QDateTime::currentDateTime().toString(Qt::ISODate) << "\n";
+    out << "CancelledBy=" << user << "\n";
+    out << "Cancelled=true\n";
+    out << "CancellationReason=" << reason << "\n";
+
+    directoryFile.close();
+
+    // Log the cancellation
+    workflowLogger.setLogPath(folderPath);
+    QStringList changes;
+    changes << QString("Status: active -> cancelled");
+    changes << QString("Reason: %1").arg(reason);
+    workflowLogger.appendToLogWithChanges(folderPath, user, changes);
+
+    // Move folder to archive
+    QFileInfo folderInfo(folderPath);
+    QString folderName = folderInfo.fileName();
+    QString targetPath = archivePath + "/" + folderName;
+
+    // Check if target already exists
+    if (QDir(targetPath).exists()) {
+        targetPath = archivePath + "/" + folderName + "_" + QDateTime::currentDateTime().toString("yyyyMMdd_HHmmss");
+    }
+
+    QDir dir;
+    if (!dir.rename(folderPath, targetPath)) {
+        workflowLogger.logError("Cancel", "Failed to move folder to archive: " + targetPath);
+        return false;
+    }
+
+    return true;
+}
