@@ -24,9 +24,11 @@ public:
 
     Q_INVOKABLE bool isAvailable() const;
     Q_INVOKABLE bool isOcrAvailable() const;
+    Q_INVOKABLE bool wasOcrApplied() const;
 
 private:
     ConfigManager *configMgr;
+    bool lastOcrApplied = false;
     bool createStampPdf(const QString &stampPath, const QString &receiptDate);
     bool applyOcr(const QString &inputPdf, const QString &outputPdf);
 };
