@@ -88,6 +88,31 @@ void WorkflowLogger::appendToLog(const QString &folderPath, const QString &user)
     }
 }
 
+void WorkflowLogger::appendToLogWithChanges(const QString &folderPath, const QString &user, const QStringList &changes)
+{
+    QString appendLogPath = folderPath + "/.workflow.log";
+
+    QFile file(appendLogPath);
+    if (file.open(QIODevice::Append | QIODevice::Text)) {
+        QTextStream out(&file);
+        out << "\n";
+        out << "=== Metadata Update ===" << "\n";
+        out << "Updated: " + QDateTime::currentDateTime().toString(Qt::ISODate) << "\n";
+        out << timestamp() + " [UPDATE] Metadata updated by: " + user << "\n";
+
+        if (!changes.isEmpty()) {
+            out << timestamp() + " [CHANGES]" << "\n";
+            for (const QString &change : changes) {
+                out << "         " + change << "\n";
+            }
+        } else {
+            out << timestamp() + " [CHANGES] No changes detected" << "\n";
+        }
+
+        file.close();
+    }
+}
+
 void WorkflowLogger::writeLog()
 {
     if (logPath.isEmpty()) {
